build_update_stream_stream

Function build_update_stream_stream 

fn build_update_stream_stream<'scope, T>(
    stream: VecCollection<'scope, T, Row, Diff>,
    _as_of: Antichain<Timestamp>,
    source_relation: usize,
    initial_closure: JoinClosure,
) -> (VecCollection<'scope, T, Row, Diff>, VecCollection<'scope, T, DataflowErrorSer, Diff>)
where T: RenderTimestamp,
Builds the beginning of the update stream of a delta path from a raw collection.

This is the unarranged counterpart of build_update_stream_trace. Only the delta path for the first relation can be seeded from a raw collection, since the as-of filtering that the other paths rely on is only available from an arrangement’s times. We assert that here.