fn build_update_stream_trace<'scope, T, Tr>(
trace: Arranged<'scope, Tr>,
as_of: Antichain<Timestamp>,
source_relation: usize,
initial_closure: JoinClosure,
) -> (VecCollection<'scope, T, Row, Diff>, VecCollection<'scope, T, DataflowErrorSer, Diff>)where
T: RenderTimestamp,
for<'a, 'b> &'a T: PartialEq<<BatchCursor<Tr> as Cursor>::TimeGat<'b>>,
Tr: TraceReader<Batch: Navigable, Time = T> + Clone + 'static,
for<'a> BatchCursor<Tr>: Cursor<Key<'a>: ExtendDatums, Val<'a>: ExtendDatums, Time = T, Diff = Diff>,Expand description
Builds the beginning of the update stream of a delta path.
At start-up time only the delta path for the first relation sees updates, since any updates fed to the other delta paths would be discarded anyway due to the tie-breaking logic that avoids double-counting updates happening at the same time on different relations.