fn build_update_stream<'scope, T>(
bundle: &CollectionBundle<'scope, T>,
as_of: Antichain<Timestamp>,
source_key: Option<Vec<LirScalarExpr>>,
source_relation: usize,
initial_closure: JoinClosure,
) -> (VecCollection<'scope, T, Row, Diff>, VecCollection<'scope, T, DataflowErrorSer, Diff>)where
T: RenderTimestamp,Expand description
Builds the initial update stream of a delta path from a collection bundle.
With a source_key, demuxes over the two flavors of arrangement the bundle might hold for that
key, dispatching to the generic build_update_stream_trace. Without a source_key, the source
relation is consumed as a raw (unarranged) collection via build_update_stream_stream.